@@ -2,55 +2,47 @@
 from .api.opencti_api_client import OpenCTIApiClient
 from .api.opencti_api_connector import OpenCTIApiConnector
 from .api.opencti_api_work import OpenCTIApiWork
-
-from .connector.opencti_connector import ConnectorType
-from .connector.opencti_connector import OpenCTIConnector
+from .connector.opencti_connector import ConnectorType, OpenCTIConnector
 from .connector.opencti_connector_helper import (
     OpenCTIConnectorHelper,
     get_config_variable,
 )
-
-from .entities.opencti_label import Label
-from .entities.opencti_marking_definition import MarkingDefinition
-from .entities.opencti_external_reference import ExternalReference
-from .entities.opencti_kill_chain_phase import KillChainPhase
-from .entities.opencti_stix_object_or_stix_relationship import (
-    StixObjectOrStixRelationship,
-)
-from .entities.opencti_stix_domain_object import StixDomainObject
-from .entities.opencti_stix_cyber_observable import StixCyberObservable
-from .entities.opencti_stix_core_relationship import StixCoreRelationship
-from .entities.opencti_stix_sighting_relationship import StixSightingRelationship
-from .entities.opencti_stix_cyber_observable_relationship import (
-    StixCyberObservableRelationship,
-)
-from .entities.opencti_identity import Identity
-from .entities.opencti_location import Location
-from .entities.opencti_threat_actor import ThreatActor
-from .entities.opencti_intrusion_set import IntrusionSet
-from .entities.opencti_infrastructure import Infrastructure
-from .entities.opencti_campaign import Campaign
-from .entities.opencti_x_opencti_incident import XOpenCTIIncident
-from .entities.opencti_malware import Malware
-from .entities.opencti_tool import Tool
-from .entities.opencti_vulnerability import Vulnerability
 from .entities.opencti_attack_pattern import AttackPattern
+from .entities.opencti_campaign import Campaign
 from .entities.opencti_course_of_action import CourseOfAction
-from .entities.opencti_report import Report
+from .entities.opencti_external_reference import ExternalReference
+from .entities.opencti_identity import Identity
+from .entities.opencti_incident import Incident
+from .entities.opencti_indicator import Indicator
+from .entities.opencti_infrastructure import Infrastructure
+from .entities.opencti_intrusion_set import IntrusionSet
+from .entities.opencti_kill_chain_phase import KillChainPhase
+from .entities.opencti_label import Label
+from .entities.opencti_location import Location
+from .entities.opencti_malware import Malware
+from .entities.opencti_marking_definition import MarkingDefinition
 from .entities.opencti_note import Note
 from .entities.opencti_observed_data import ObservedData
 from .entities.opencti_opinion import Opinion
-from .entities.opencti_indicator import Indicator
-
+from .entities.opencti_report import Report
+from .entities.opencti_stix_core_relationship import StixCoreRelationship
+from .entities.opencti_stix_cyber_observable import StixCyberObservable
+from .entities.opencti_stix_cyber_observable_relationship import (
+    StixCyberObservableRelationship,
+)
+from .entities.opencti_stix_domain_object import StixDomainObject
+from .entities.opencti_stix_object_or_stix_relationship import (
+    StixObjectOrStixRelationship,
+)
+from .entities.opencti_stix_sighting_relationship import StixSightingRelationship
+from .entities.opencti_threat_actor import ThreatActor
+from .entities.opencti_tool import Tool
+from .entities.opencti_vulnerability import Vulnerability
+from .utils.constants import StixCyberObservableTypes
 from .utils.opencti_stix2 import OpenCTIStix2
 from .utils.opencti_stix2_splitter import OpenCTIStix2Splitter
 from .utils.opencti_stix2_update import OpenCTIStix2Update
-from .utils.opencti_stix2_utils import (
-    OpenCTIStix2Utils,
-    SimpleObservable,
-    StixXOpenCTIIncident,
-)
-from .utils.constants import StixCyberObservableTypes
+from .utils.opencti_stix2_utils import OpenCTIStix2Utils, SimpleObservable, StixIncident
 
 __all__ = [
     "OpenCTIApiClient",
@@ -76,7 +68,7 @@ __all__ = [
     "IntrusionSet",
     "Infrastructure",
     "Campaign",
-    "XOpenCTIIncident",
+    "Incident",
     "Malware",
     "Tool",
     "Vulnerability",
@@ -93,5 +85,5 @@ __all__ = [
     "OpenCTIStix2Utils",
     "StixCyberObservableTypes",
     "SimpleObservable",
-    "StixXOpenCTIIncident",
+    "StixIncident",
 ]
