@@ -1,26 +1,22 @@
-import datetime
-import threading
-import queue
-import uuid
-import requests
-
-import pika
-import logging
-import json
-import time
 import base64
+import datetime
+import json
+import logging
 import os
 import ssl
+import threading
+import time
+import uuid
+from typing import Callable, Dict, List, Optional, Union
 
-from typing import Callable, Dict, Optional, Union
+import pika
+from pika.exceptions import NackError, UnroutableError
 from sseclient import SSEClient
-from pika.exceptions import UnroutableError, NackError
+
 from pycti.api.opencti_api_client import OpenCTIApiClient
 from pycti.connector.opencti_connector import OpenCTIConnector
 from pycti.utils.opencti_stix2_splitter import OpenCTIStix2Splitter
 
-EVENTS_QUEUE = queue.Queue()
-
 
 def get_config_variable(
     env_var: str,
@@ -63,19 +59,17 @@ def create_ssl_context() -> ssl.SSLContext:
     `ssl` uses bitwise operations to specify context `<enum 'Options'>`
     """
 
-    ssl_context_options: list[int] = [
+    ssl_context_options: List[int] = [
         ssl.OP_NO_COMPRESSION,
         ssl.OP_NO_TICKET,  # pylint: disable=no-member
         ssl.OP_NO_RENEGOTIATION,  # pylint: disable=no-member
         ssl.OP_SINGLE_DH_USE,
         ssl.OP_SINGLE_ECDH_USE,
-        ssl.OP_NO_SSLv3,
-        ssl.OP_NO_TLSv1,
-        ssl.OP_NO_TLSv1_1,
     ]
     ssl_context = ssl.create_default_context(purpose=ssl.Purpose.SERVER_AUTH)
     ssl_context.options &= ~ssl.OP_ENABLE_MIDDLEBOX_COMPAT  # pylint: disable=no-member
     ssl_context.verify_mode = ssl.CERT_REQUIRED
+    ssl_context.minimum_version = ssl.TLSVersion.TLSv1_2
 
     for option in ssl_context_options:
         ssl_context.options |= option
@@ -150,7 +144,6 @@ class ListenQueue(threading.Thread):
             )
             message = self.callback(json_data["event"])
             self.helper.api.work.to_processed(work_id, message)
-
         except Exception as e:
             logging.exception("Error in message processing, reporting error to API")
             try:
@@ -225,81 +218,113 @@ class PingAlive(threading.Thread):
         self.ping()
 
 
-class StreamCatcher(threading.Thread):
-    def __init__(
-        self,
-        opencti_url,
-        opencti_token,
-        connector_last_event_id,
-        last_event_id,
-        stream_connection_id,
-    ):
+class ListenStream(threading.Thread):
+    def __init__(self, helper, callback, url, token, verify_ssl, start_timestamp):
         threading.Thread.__init__(self)
-        self.opencti_url = opencti_url
-        self.opencti_token = opencti_token
-        self.connector_last_event_id = connector_last_event_id
-        self.last_event_id = last_event_id
-        self.stream_connection_id = stream_connection_id
-        self.session = requests.session()
-
-    def get_range(self, from_id):
-        payload = {
-            "from": from_id,
-            "size": 2000,
-            "connectionId": self.stream_connection_id,
-        }
-        headers = {"Authorization": "Bearer " + self.opencti_token}
-        r = self.session.post(
-            self.opencti_url + "/stream/history", json=payload, headers=headers
-        )
-        result = r.json()
-        if result and "lastEventId" in result:
-            return result["lastEventId"]
+        self.helper = helper
+        self.callback = callback
+        self.url = url
+        self.token = token
+        self.verify_ssl = verify_ssl
+        self.start_timestamp = start_timestamp
 
     def run(self):
-        if self.connector_last_event_id:
-            from_event_id = self.connector_last_event_id
-            # If from event ID is "-", start from the beginning
-            if from_event_id == "-":
-                from_event_timestamp = 0
-            # If from event ID is a "pure" timestamp
-            elif "-" not in str(from_event_id):
-                from_event_timestamp = int(from_event_id)
-            elif "-" in str(from_event_id):
-                from_event_timestamp = int(str(from_event_id).split("-")[0])
+        current_state = self.helper.get_state()
+        if current_state is None:
+            current_state = {
+                "connectorLastEventId": str(self.start_timestamp) + "-0"
+                if self.start_timestamp is not None and len(self.start_timestamp) > 0
+                else "-"
+            }
+            self.helper.set_state(current_state)
+
+        # If URL and token are provided, likely consuming a remote stream
+        if self.url is not None and self.token is not None:
+            # If a live stream ID, appending the URL
+            live_stream_uri = (
+                ("/" + self.helper.connect_live_stream_id)
+                if self.helper.connect_live_stream_id is not None
+                else ""
+            )
+            # Live stream "from" should be empty if start from the beginning
+            if self.helper.connect_live_stream_id is not None:
+                live_stream_from = (
+                    ("?from=" + current_state["connectorLastEventId"])
+                    if current_state["connectorLastEventId"] != "-"
+                    else ""
+                )
+            # Global stream "from" should be 0 if starting from the beginning
             else:
-                from_event_timestamp = 0
-            last_event_timestamp = int(self.last_event_id.split("-")[0])
-            if from_event_timestamp > last_event_timestamp:
-                from_event_timestamp = last_event_timestamp - 1
-                from_event_id = str(from_event_timestamp) + "-0"
-            while (
-                from_event_timestamp <= last_event_timestamp
-                and from_event_id != self.last_event_id
-            ):
-                from_event_id = self.get_range(from_event_id)
-                from_event_timestamp = int(from_event_id.split("-")[0])
-        logging.info("Events catchup requests done.")
-
-
-class StreamProcessor(threading.Thread):
-    def __init__(self, message_callback, get_state, set_state):
-        threading.Thread.__init__(self)
-        self.message_callback = message_callback
-        self.get_state = get_state
-        self.set_state = set_state
-
-    def run(self):
-        logging.info("All old events processed, consuming is now LIVE!")
-        while True:
-            msg = EVENTS_QUEUE.get(block=True, timeout=None)
-            self.message_callback(msg)
-            state = self.get_state()
-            if state is not None:
-                state["connectorLastEventId"] = msg.id
-                self.set_state(state)
+                live_stream_from = "?from=" + (
+                    current_state["connectorLastEventId"]
+                    if current_state["connectorLastEventId"] != "-"
+                    else "0"
+                )
+            live_stream_url = self.url + "/stream" + live_stream_uri + live_stream_from
+            opencti_ssl_verify = (
+                self.verify_ssl if self.verify_ssl is not None else True
+            )
+            logging.info(
+                "Starting listening stream events (URL: "
+                + live_stream_url
+                + ", SSL verify: "
+                + str(opencti_ssl_verify)
+                + ")"
+            )
+            messages = SSEClient(
+                live_stream_url,
+                headers={"Authorization": "Bearer " + self.token},
+                verify=opencti_ssl_verify,
+            )
+        else:
+            live_stream_uri = (
+                ("/" + self.helper.connect_live_stream_id)
+                if self.helper.connect_live_stream_id is not None
+                else ""
+            )
+            if self.helper.connect_live_stream_id is not None:
+                live_stream_from = (
+                    ("?from=" + current_state["connectorLastEventId"])
+                    if current_state["connectorLastEventId"] != "-"
+                    else ""
+                )
+            # Global stream "from" should be 0 if starting from the beginning
             else:
-                self.set_state({"connectorLastEventId": msg.id})
+                live_stream_from = "?from=" + (
+                    current_state["connectorLastEventId"]
+                    if current_state["connectorLastEventId"] != "-"
+                    else "0"
+                )
+            live_stream_url = (
+                self.helper.opencti_url + "/stream" + live_stream_uri + live_stream_from
+            )
+            logging.info(
+                "Starting listening stream events (URL: "
+                + live_stream_url
+                + ", SSL verify: "
+                + str(self.helper.opencti_ssl_verify)
+                + ")"
+            )
+            messages = SSEClient(
+                live_stream_url,
+                headers={"Authorization": "Bearer " + self.helper.opencti_token},
+                verify=self.helper.opencti_ssl_verify,
+            )
+
+        for msg in messages:
+            if msg.event == "heartbeat" or msg.event == "connected":
+                continue
+            elif msg.event == "sync":
+                if msg.id is not None:
+                    state = self.helper.get_state()
+                    state["connectorLastEventId"] = str(msg.id)
+                    self.helper.set_state(state)
+            else:
+                self.callback(msg)
+                if msg.id is not None:
+                    state = self.helper.get_state()
+                    state["connectorLastEventId"] = str(msg.id)
+                    self.helper.set_state(state)
 
 
 class OpenCTIConnectorHelper:
@@ -327,6 +352,13 @@ class OpenCTIConnectorHelper:
         self.connect_type = get_config_variable(
             "CONNECTOR_TYPE", ["connector", "type"], config
         )
+        self.connect_live_stream_id = get_config_variable(
+            "CONNECTOR_LIVE_STREAM_ID",
+            ["connector", "live_stream_id"],
+            config,
+            False,
+            None,
+        )
         self.connect_name = get_config_variable(
             "CONNECTOR_NAME", ["connector", "name"], config
         )
@@ -342,12 +374,21 @@ class OpenCTIConnectorHelper:
         self.connect_auto = get_config_variable(
             "CONNECTOR_AUTO", ["connector", "auto"], config, False, False
         )
+        self.connect_only_contextual = get_config_variable(
+            "CONNECTOR_ONLY_CONTEXTUAL",
+            ["connector", "only_contextual"],
+            config,
+            False,
+            False,
+        )
         self.log_level = get_config_variable(
             "CONNECTOR_LOG_LEVEL", ["connector", "log_level"], config
         )
 
         # Configure logger
-        numeric_level = getattr(logging, self.log_level.upper(), None)
+        numeric_level = getattr(
+            logging, self.log_level.upper() if self.log_level else "INFO", None
+        )
         if not isinstance(numeric_level, int):
             raise ValueError("Invalid log level: " + self.log_level)
         logging.basicConfig(level=numeric_level)
@@ -363,6 +404,7 @@ class OpenCTIConnectorHelper:
             self.connect_type,
             self.connect_scope,
             self.connect_auto,
+            self.connect_only_contextual,
         )
         connector_configuration = self.api.connector.register(self.connector)
         logging.info("Connector registered with ID:" + self.connect_id)
@@ -381,6 +423,9 @@ class OpenCTIConnectorHelper:
     def get_name(self):
         return self.connect_name
 
+    def get_only_contextual(self):
+        return self.connect_only_contextual
+
     def set_state(self, state) -> None:
         """sets the connector state
 
@@ -406,108 +451,33 @@ class OpenCTIConnectorHelper:
             pass
         return None
 
-    def listen(self, message_callback: Callable[[str, Dict], str]) -> None:
+    def listen(self, message_callback: Callable[[Dict], str]) -> None:
         """listen for messages and register callback function
 
         :param message_callback: callback function to process messages
-        :type message_callback: Callable[[Dict], List[str]]
+        :type message_callback: Callable[[Dict], str]
         """
 
         listen_queue = ListenQueue(self, self.config, message_callback)
         listen_queue.start()
 
     def listen_stream(
-        self, message_callback, url=None, token=None, verify=None
+        self,
+        message_callback,
+        url=None,
+        token=None,
+        verify_ssl=None,
+        start_timestamp=None,
     ) -> None:
         """listen for messages and register callback function
 
         :param message_callback: callback function to process messages
         """
-        current_state = self.get_state()
-        if current_state is None:
-            current_state = {"connectorLastEventId": "-"}
 
-        # Get the last event ID with the "connected" event msg
-        if url is not None and token is not None:
-            opencti_ssl_verify = verify if verify is not None else True
-            logging.info(
-                "Starting listening stream events with SSL verify to: "
-                + str(opencti_ssl_verify)
-            )
-            messages = SSEClient(
-                url + "/stream",
-                headers={"Authorization": "Bearer " + token},
-                verify=opencti_ssl_verify,
-            )
-        else:
-            logging.info(
-                "Starting listening stream events with SSL verify to: "
-                + str(self.opencti_ssl_verify)
-            )
-            messages = SSEClient(
-                self.opencti_url + "/stream",
-                headers={"Authorization": "Bearer " + self.opencti_token},
-                verify=self.opencti_ssl_verify,
-            )
-
-        # Create processor thread
-        processor_thread = StreamProcessor(
-            message_callback, self.get_state, self.set_state
+        listen_stream = ListenStream(
+            self, message_callback, url, token, verify_ssl, start_timestamp
         )
-
-        last_event_id = None
-        for msg in messages:
-            try:
-                data = json.loads(msg.data)
-            except:
-                logging.error("Failed to load JSON: " + msg.data)
-                continue
-            if msg.event == "heartbeat":
-                logging.info("HEARTBEAT:" + str(msg))
-                continue
-            elif msg.event == "connected":
-                last_event_id = data["lastEventId"]
-                stream_connection_id = data["connectionId"]
-                # Launch processor if up to date
-                if current_state["connectorLastEventId"] == last_event_id:
-                    processor_thread.start()
-                # Launch catcher if not up to date
-                if last_event_id != current_state["connectorLastEventId"]:
-                    logging.info(
-                        "Some events have not been processed, catching them..."
-                    )
-                    if url is not None and token is not None:
-                        catcher_thread = StreamCatcher(
-                            url,
-                            token,
-                            current_state["connectorLastEventId"],
-                            last_event_id,
-                            stream_connection_id,
-                        )
-                    else:
-                        catcher_thread = StreamCatcher(
-                            self.opencti_url,
-                            self.opencti_token,
-                            current_state["connectorLastEventId"],
-                            last_event_id,
-                            stream_connection_id,
-                        )
-                    catcher_thread.start()
-            else:
-                # If receiving the last message, launch processor
-                if msg.id == last_event_id:
-                    message_callback(msg)
-                    processor_thread.start()
-                elif "catchup" not in data:
-                    EVENTS_QUEUE.put(msg)
-                else:
-                    message_callback(msg)
-                    state = self.get_state()
-                    if state is not None:
-                        state["connectorLastEventId"] = msg.id
-                        self.set_state(state)
-                    else:
-                        self.set_state({"connectorLastEventId": msg.id})
+        listen_stream.start()
 
     def get_opencti_url(self):
         return self.opencti_url
@@ -524,6 +494,12 @@ class OpenCTIConnectorHelper:
     def log_info(self, msg):
         logging.info(msg)
 
+    def log_debug(self, msg):
+        logging.debug(msg)
+
+    def log_warning(self, msg):
+        logging.warning(msg)
+
     def date_now(self) -> str:
         """get the current date (UTC)
         :return: current datetime for utc
@@ -553,11 +529,12 @@ class OpenCTIConnectorHelper:
         work_id = kwargs.get("work_id", self.work_id)
         entities_types = kwargs.get("entities_types", None)
         update = kwargs.get("update", False)
+        event_version = kwargs.get("event_version", None)
 
         if entities_types is None:
             entities_types = []
         stix2_splitter = OpenCTIStix2Splitter()
-        bundles = stix2_splitter.split_bundle(bundle)
+        bundles = stix2_splitter.split_bundle(bundle, True, event_version)
         if len(bundles) == 0:
             raise ValueError("Nothing to import")
         if work_id is not None:
