@@ -162,7 +162,7 @@ class StixCoreRelationship:
                 ... on Vulnerability {
                     name
                 }
-                ... on XOpenCTIIncident {
+                ... on Incident {
                     name
                 }         
                 ... on StixCyberObservable {
@@ -243,7 +243,7 @@ class StixCoreRelationship:
                 ... on Vulnerability {
                     name
                 }
-                ... on XOpenCTIIncident {
+                ... on Incident {
                     name
                 }
                 ... on StixCyberObservable {
@@ -535,6 +535,10 @@ class StixCoreRelationship:
         id = kwargs.get("id", None)
         key = kwargs.get("key", None)
         value = kwargs.get("value", None)
+        if isinstance(value, list):
+            value = [str(v) for v in value]
+        else:
+            value = str(value)
         if id is not None and key is not None and value is not None:
             self.opencti.log(
                 "info",
@@ -545,6 +549,8 @@ class StixCoreRelationship:
                         stixCoreRelationshipEdit(id: $id) {
                             fieldPatch(input: $input) {
                                 id
+                                standard_id
+                                entity_type
                             }
                         }
                     }
