@@ -135,9 +135,18 @@ class StixCyberObservable:
                 encryption_algorithm
                 decryption_key
                 hashes {
-                  algorithm
-                  hash
-                }           
+                    algorithm
+                    hash
+                }
+                importFiles {
+                    edges {
+                        node {
+                            id
+                            name
+                            size
+                        }
+                    }
+                }                
             }        
             ... on StixFile {
                 extensions
@@ -1069,7 +1078,10 @@ class StixCyberObservable:
         key = kwargs.get("key", None)
         value = kwargs.get("value", None)
         operation = kwargs.get("operation", "replace")
-
+        if isinstance(value, list):
+            value = [str(v) for v in value]
+        else:
+            value = str(value)
         if id is not None and key is not None and value is not None:
             self.opencti.log(
                 "info", "Updating Stix-Observable {" + id + "} field {" + key + "}."
@@ -1080,6 +1092,7 @@ class StixCyberObservable:
                         fieldPatch(input: $input, operation: $operation) {
                             id
                             standard_id
+                            entity_type
                         }
                     }
                 }
