@@ -160,7 +160,7 @@ class StixSightingRelationship:
                 ... on Vulnerability {
                     name
                 }
-                ... on XOpenCTIIncident {
+                ... on Incident {
                     name
                 }           
                 ... on StixCyberObservable {
@@ -241,7 +241,7 @@ class StixSightingRelationship:
                 ... on Vulnerability {
                     name
                 }
-                ... on XOpenCTIIncident {
+                ... on Incident {
                     name
                 }
                 ... on StixCyberObservable {
@@ -271,6 +271,7 @@ class StixSightingRelationship:
     """
 
     def list(self, **kwargs):
+        element_id = kwargs.get("elementId", None)
         from_id = kwargs.get("fromId", None)
         from_types = kwargs.get("fromTypes", None)
         to_id = kwargs.get("toId", None)
@@ -280,14 +281,14 @@ class StixSightingRelationship:
         last_seen_start = kwargs.get("lastSeenStart", None)
         last_seen_stop = kwargs.get("lastSeenStop", None)
         filters = kwargs.get("filters", [])
-        first = kwargs.get("first", 500)
+        first = kwargs.get("first", 100)
         after = kwargs.get("after", None)
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
         if get_all:
-            first = 500
+            first = 100
 
         self.opencti.log(
             "info",
@@ -299,8 +300,8 @@ class StixSightingRelationship:
         )
         query = (
             """
-                query StixSightingRelationships($fromId: String, $fromTypes: [String], $toId: String, $toTypes: [String], $firstSeenStart: DateTime, $firstSeenStop: DateTime, $lastSeenStart: DateTime, $lastSeenStop: DateTime, $filters: [StixSightingRelationshipsFiltering], $first: Int, $after: ID, $orderBy: StixSightingRelationshipsOrdering, $orderMode: OrderingMode) {
-                    stixSightingRelationships(fromId: $fromId, fromTypes: $fromTypes, toId: $toId, toTypes: $toTypes, firstSeenStart: $firstSeenStart, firstSeenStop: $firstSeenStop, lastSeenStart: $lastSeenStart, lastSeenStop: $lastSeenStop, filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
+                query StixSightingRelationships($elementId: String, $fromId: String, $fromTypes: [String], $toId: String, $toTypes: [String], $firstSeenStart: DateTime, $firstSeenStop: DateTime, $lastSeenStart: DateTime, $lastSeenStop: DateTime, $filters: [StixSightingRelationshipsFiltering], $first: Int, $after: ID, $orderBy: StixSightingRelationshipsOrdering, $orderMode: OrderingMode) {
+                    stixSightingRelationships(elementId: $elementId, fromId: $fromId, fromTypes: $fromTypes, toId: $toId, toTypes: $toTypes, firstSeenStart: $firstSeenStart, firstSeenStop: $firstSeenStop, lastSeenStart: $lastSeenStart, lastSeenStop: $lastSeenStop, filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                         edges {
                             node {
                                 """
@@ -322,6 +323,7 @@ class StixSightingRelationship:
         result = self.opencti.query(
             query,
             {
+                "elementId": element_id,
                 "fromId": from_id,
                 "fromTypes": from_types,
                 "toId": to_id,
@@ -337,9 +339,49 @@ class StixSightingRelationship:
                 "orderMode": order_mode,
             },
         )
-        return self.opencti.process_multiple(
-            result["data"]["stixSightingRelationships"], with_pagination
-        )
+        if get_all:
+            final_data = []
+            data = self.opencti.process_multiple(
+                result["data"]["stixSightingRelationships"]
+            )
+            final_data = final_data + data
+            while result["data"]["stixSightingRelationships"]["pageInfo"][
+                "hasNextPage"
+            ]:
+                after = result["data"]["stixSightingRelationships"]["pageInfo"][
+                    "endCursor"
+                ]
+                self.opencti.log(
+                    "info", "Listing StixSightingRelationships after " + after
+                )
+                result = self.opencti.query(
+                    query,
+                    {
+                        "elementId": element_id,
+                        "fromId": from_id,
+                        "fromTypes": from_types,
+                        "toId": to_id,
+                        "toTypes": to_types,
+                        "firstSeenStart": first_seen_start,
+                        "firstSeenStop": first_seen_stop,
+                        "lastSeenStart": last_seen_start,
+                        "lastSeenStop": last_seen_stop,
+                        "filters": filters,
+                        "first": first,
+                        "after": after,
+                        "orderBy": order_by,
+                        "orderMode": order_mode,
+                    },
+                )
+                data = self.opencti.process_multiple(
+                    result["data"]["stixSightingRelationships"]
+                )
+                final_data = final_data + data
+            return final_data
+        else:
+            return self.opencti.process_multiple(
+                result["data"]["stixSightingRelationships"], with_pagination
+            )
 
     """
         Read a stix_sighting object
@@ -356,6 +398,7 @@ class StixSightingRelationship:
 
     def read(self, **kwargs):
         id = kwargs.get("id", None)
+        element_id = kwargs.get("elementId", None)
         from_id = kwargs.get("fromId", None)
         to_id = kwargs.get("toId", None)
         first_seen_start = kwargs.get("firstSeenStart", None)
@@ -386,6 +429,7 @@ class StixSightingRelationship:
             )
         elif from_id is not None and to_id is not None:
             result = self.list(
+                elementId=element_id,
                 fromId=from_id,
                 toId=to_id,
                 firstSeenStart=first_seen_start,
